@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: MapDraw.cpp,v 1.8 2007/03/25 20:48:24 leonb Exp $
-// $Name: release_3_5_20_2 $
+// $Id: MapDraw.cpp,v 1.9 2008/08/05 20:52:26 bpearlmutter Exp $
+// $Name: release_3_5_23 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -78,26 +78,29 @@ void
 MapDraw::drawPixel(GPixmap & pm, int x, int y, bool eor,
 		   u_char r, u_char g, u_char b)
 {
-   if (y>=0 && y<(int) pm.rows())
+  if (y>=0 && y<(int) pm.rows())
+    {
       if (eor)
-      {
-	 GPixel * pix=pm[pm.rows()-1-y]+x;
-	 if (x>=0 && x<(int) pm.columns())
-	 {
-	    pix->r^=0xff;
-	    pix->g^=0xff;
-	    pix->b^=0xff;
-	 }
-      } else
-      {
-	 GPixel * pix=pm[pm.rows()-1-y]+x;
-	 if (x>=0 && x<(int) pm.columns())
-	 {
-	    pix->r=r;
-	    pix->g=g;
-	    pix->b=b;
-	 }
-      }
+	{
+	  GPixel * pix=pm[pm.rows()-1-y]+x;
+	  if (x>=0 && x<(int) pm.columns())
+	    {
+	      pix->r^=0xff;
+	      pix->g^=0xff;
+	      pix->b^=0xff;
+	    }
+	}
+      else
+	{
+	  GPixel * pix=pm[pm.rows()-1-y]+x;
+	  if (x>=0 && x<(int) pm.columns())
+	    {
+	      pix->r=r;
+	      pix->g=g;
+	      pix->b=b;
+	    }
+	}
+    }
 }
 
 void
