@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: GContainer.h,v 1.20 2007/05/19 03:07:33 leonb Exp $
-// $Name: release_3_5_20_2 $
+// $Id: GContainer.h,v 1.21 2008/01/07 11:48:52 leonb Exp $
+// $Name: release_3_5_23 $
 
 #ifndef _GCONTAINER_H_
 #define _GCONTAINER_H_
@@ -132,7 +132,7 @@ namespace DJVU {
     L\'eon Bottou <leonb@research.att.com> -- initial implementation.\\
     Andrei Erofeev <eaf@geocities.com> -- bug fixes.
     @version 
-    #$Id: GContainer.h,v 1.20 2007/05/19 03:07:33 leonb Exp $# */
+    #$Id: GContainer.h,v 1.21 2008/01/07 11:48:52 leonb Exp $# */
 //@{
 
 
@@ -281,14 +281,14 @@ protected:
       { return (void*)( ((T*)base) + n ); }
     // Template based default constructor
     static void init(void* dst, int n) 
-      { T* d = (T*)dst;   while (--n>=0) { new ((void*)d) T; d++; } }
+      { T* d = (T*)dst; while (--n>=0) { new ((void*)d) T; d++; } }
     // Template based copy constructor
     static void copy(void* dst, const void* src, int n, int zap)
-      { T* d = (T*)dst; const T *s = (const T*)src; 
-        while (--n>=0) { new ((void*)d) T(*s); if (zap) { s->T::~T(); }; d++; s++; } }
+      { T* d = (T*)dst; T* s = (T*)src; while (--n>=0) { 
+          new ((void*)d) T(*s); if (zap) { s->~T(); }; d++; s++; } }
     // Template based destructor
     static void fini(void* dst, int n) 
-      { T* d = (T*)dst; while (--n>=0) { d->T::~T(); d++; } }
+      { T* d = (T*)dst; while (--n>=0) { d->~T(); d++; } }
   };
   // --- Base class for list nodes
   struct Node
