@@ -54,7 +54,7 @@
 //C- +------------------------------------------------------------------
 */
 
-/* $Id: ddjvuapi.h,v 1.62 2007/05/19 03:07:34 leonb Exp $ */
+/* $Id: ddjvuapi.h,v 1.70 2010/06/27 20:31:07 leonb Exp $ */
 
 #ifndef DDJVUAPI_H
 #define DDJVUAPI_H
@@ -112,6 +112,8 @@ extern "C" {
 
    Version   Change
    -----------------------------
+     19    Added:
+              ddjvu_document_create_by_filename_utf8
      18    Added:
               ddjvu_document_get_{anno,pagedump,filedump}()
            Modifed (binary compatible):
@@ -133,9 +135,7 @@ extern "C" {
      14    Initial version.
 */
 
-#define DDJVUAPI_VERSION 18
-
-
+#define DDJVUAPI_VERSION 19
 
 typedef struct ddjvu_context_s    ddjvu_context_t;
 typedef union  ddjvu_message_s    ddjvu_message_t;
@@ -352,7 +352,7 @@ ddjvu_job_stop(ddjvu_job_t *job);
 
 /* ddjvu_job_set_user_data ---
    ddjvu_job_get_user_data ---
-   Each job can store an arbitray pointer
+   Each job can store an arbitrary pointer
    that callers can use for any purpose. These two 
    functions provide for accessing or setting this pointer. 
    This pointer is cleared when the job is released */
@@ -489,8 +489,8 @@ struct ddjvu_message_info_s {   /* ddjvu_message_t::m_info */
    and <ddjvu_stream_close>.
 
    Localized characters in argument <url> should be in 
-   urlencoded utf-8 (like "%2A"). What is happening for non 
-   ascii characters is unclear (probably plain utf8). */
+   urlencoded UTF-8 (like "%2A"). What is happening for non 
+   ascii characters is unclear (probably UTF-8). */
 
 DDJVUAPI ddjvu_document_t *
 ddjvu_document_create(ddjvu_context_t *context,
@@ -501,13 +501,19 @@ ddjvu_document_create(ddjvu_context_t *context,
 /* ddjvu_document_create_by_filename ---
    Creates a document for a DjVu document stored in a file.
    The document will directly access the specified DjVu file 
-   or related files without generating <m_newstream> messages. */
+   or related files without generating <m_newstream> messages.
+   The standard function expects the filename in locale encoding. 
+   The utf8 variant expects an utf8 encoded filename. */
 
 DDJVUAPI ddjvu_document_t *
 ddjvu_document_create_by_filename(ddjvu_context_t *context,
                                   const char *filename,
                                   int cache);
 
+DDJVUAPI ddjvu_document_t *
+ddjvu_document_create_by_filename_utf8(ddjvu_context_t *context,
+                                       const char *filename,
+                                       int cache);
 
 /* ddjvu_document_job ---
    Access the job object in charge of decoding the document header. 
@@ -572,15 +578,15 @@ ddjvu_document_job(ddjvu_document_t *document);
    object is created.
 
    Further <m_newstream> messages are generated to access
-   the auxilliary files of indirect or indexed DjVu
+   the auxiliary files of indirect or indexed DjVu
    documents.  Member <name> then provides the basename of
-   the auxilliary file.
+   the auxiliary file.
 
    Member <url> is set according to the url argument
    provided to function <ddjvu_document_create>.  The first
    newstream message always contain the url passed to
    <ddjvu_document_create>.  Subsequent newstream messages
-   contain the url of the auxilliary files for indirect or
+   contain the url of the auxiliary files for indirect or
    indexed DjVu documents. */
    
 struct ddjvu_message_newstream_s { /* ddjvu_message_t::m_newstream */
@@ -921,7 +927,7 @@ struct ddjvu_message_chunk_s {     /* ddjvu_message_t::m_chunk */
    When receiving <m_relayout>, the viewer should get the image size, decide
    zoom factors, and place the image area, scrollbars, toolbars, and other gui
    objects.  When receiving <m_redisplay>, the viewer should invalidate the
-   image area so that the gui toolkint calls the repaint event handler. This
+   image area so that the gui toolkit calls the repaint event handler. This
    handler should call ddjvu_page_render() and paint the part of the
    image that needs repainting. */
 
@@ -945,7 +951,7 @@ DDJVUAPI int
 ddjvu_page_get_height(ddjvu_page_t *page);
 
 /* ddjvu_page_get_resolution ---
-   Returns the page resolution in pixels per inche (dpi).
+   Returns the page resolution in pixels per inch  (dpi).
    Calling this function before receiving a <m_pageinfo>
    message yields a meaningless but plausible value. */
 
@@ -1350,7 +1356,8 @@ ddjvu_document_print(ddjvu_document_t *document, FILE *output,
      Reordering or duplicating pages is prohibited. 
    * Option "-indirect=<filename>" causes the creation
      of an indirect document with index file <filename>
-     and auxilliary files in the same directory.
+     and auxiliary files in the same directory.
+     The file name is UTF-8 encoded.
      When this option is specified, the argument <output>
      is ignored and should be NULL.
 */
@@ -1428,13 +1435,18 @@ ddjvu_document_get_outline(ddjvu_document_t *document);
 /* ddjvu_document_get_anno --
    This function returns the document-wide annotations.
    This corresponds to a proposed change in the djvu format.
-   This function returns <miniexp_dummy> is the information
-   is not yet available. It may then cause the emission 
-   of <m_pageinfo> messages with null <m_any.page>.
    When no new-style document-wide annotations are available
    and <compat> is true, this function searches a shared 
    annotation chunk and returns its contents.
-*/   
+
+   This function returns <miniexp_dummy> if the information
+   is not yet available. It may then cause the emission 
+   of <m_pageinfo> messages with null <m_any.page>.
+
+   This function returns the empty list <miniexp_nil> when
+   the document does not contain page annotations. It can also
+   return symbols <failed> or <stopped> when an error occurs
+   while accessing the desired information. */
 
 DDJVUAPI miniexp_t
 ddjvu_document_get_anno(ddjvu_document_t *document, int compat);
@@ -1460,8 +1472,8 @@ ddjvu_document_get_anno(ddjvu_document_t *document, int compat);
    accessing the desired information. 
 
    Argument <maxdetail> controls the level of detail in the
-   returned s-expression. Values "page", "region", "para", 
-   or "line" restrict the output to the specified granularity.
+   returned s-expression. Values "page", "column", "region", "para", 
+   "line", and "word" restrict the output to the specified granularity.
    All other values produce a s-expression that represents
    the hidden text data as finely as possible. */
 
@@ -1546,7 +1558,7 @@ ddjvu_anno_get_vertalign(miniexp_t annotations);
 /* ddjvu_anno_get_hyperlinks --
    Parse the annotations and returns a zero terminated 
    array of <(maparea ...)> s-expressions.
-   The called should free this array with function <free>.
+   The caller should free this array with function <free>.
    These s-expressions remain allocated as long
    as the annotations remain allocated.
    See also <(maparea ...)> in the djvused man page. */
@@ -1558,7 +1570,7 @@ ddjvu_anno_get_hyperlinks(miniexp_t annotations);
 /* ddjvu_anno_get_metadata_keys --
    Parse the annotations and returns a zero terminated 
    array of key symbols for the page metadata.
-   The called should free this array with function <free>.
+   The caller should free this array with function <free>.
    See also <(metadata ...)> in the djvused man page. */
 
 DDJVUAPI miniexp_t *
