@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: c44.cpp,v 1.13 2007/03/25 20:48:35 leonb Exp $
-// $Name: release_3_5_20_2 $
+// $Id: c44.cpp,v 1.15 2010/05/27 20:47:57 leonb Exp $
+// $Name: release_3_5_23 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -211,7 +211,7 @@
     @author
     L\'eon Bottou <leonb@research.att.com>
     @version
-    #$Id: c44.cpp,v 1.13 2007/03/25 20:48:35 leonb Exp $# */
+    #$Id: c44.cpp,v 1.15 2010/05/27 20:47:57 leonb Exp $# */
 //@{
 //@}
 
@@ -692,6 +692,7 @@ int
 main(int argc, char **argv)
 {
   setlocale(LC_ALL,"");
+  setlocale(LC_NUMERIC,"C");
   djvu_programname(argv[0]);
   GArray<GUTF8String> dargv(0,argc-1);
   for(int i=0;i<argc;++i)
@@ -704,7 +705,8 @@ main(int argc, char **argv)
       GP<ByteStream> gibs=ByteStream::create(g().pnmurl,"rb");
       ByteStream &ibs=*gibs;
       char prefix[16];
-      if (ibs.readall((void*)prefix, sizeof(prefix)) != sizeof(prefix))
+      memset(prefix, 0, sizeof(prefix));
+      if (ibs.read((void*)prefix, sizeof(prefix)) < 0)
         G_THROW( ERR_MSG("c44.failed_pnm_header") );
 #ifdef DEFAULT_JPEG_TO_HALF_SIZE
       // Default specification for jpeg files
