@@ -53,7 +53,7 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: djvups.cpp,v 1.20 2007/12/02 04:14:45 leonb Exp $
+// $Id: djvups.cpp,v 1.22 2008/07/02 23:16:14 leonb Exp $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -165,7 +165,9 @@ const char *options[] = {
   I18N("-copies=<1...999999>                (default: 1)"),
   I18N("-frame=<yes|no>                     (default: no)"),
   I18N("-cropmarks=<yes|no>                 (default: no)"),
+#ifdef THIS_THING_DOES_NOT_WORK_WITH_UTF8_STRINGS
   I18N("-text=<yes|no>                      (default: no)"),
+#endif
   I18N("-booklet=<no|recto|verso|yes>       (default: no)"),
   I18N("-bookletmax=<n>                     (default: 0)"),
   I18N("-bookletalign=<n>                   (default: 0)"),
@@ -270,12 +272,19 @@ main(int argc, char **argv)
     die(i18n("Cannot open output file '%s'."), outfile);
   /* Create printing job */
   if (! (job = ddjvu_document_print(doc, fout, optc, optv)))
-    die(i18n("Cannot create print job."));
+    die(i18n("Cannot create PostScript conversion job."));
   /* Wait until completion and cleanup */
   while (! ddjvu_job_done(job))
     handle(TRUE);
   if (verbose)
     fprintf(stderr,"\n");
+  /* Make sure we get error messages */
+  tryhelp = false;
+  if (ddjvu_job_error(job))
+    handle(FALSE);
+  if (ddjvu_job_error(job))
+    die(i18n("PostScript conversion job failed."));
+  /* Close */
   fclose(fout);
   if (job)
     ddjvu_job_release(job);
